# JACK/Mixing Board


Kaithem includes an audio mixer that uses Pipewire and pw-jack.  It will not
work on any other audio backend.

The mixing board is based on channel strips, which should be familiar if you have used a physical mixing board.